<template>
  <div>
    <el-dialog
      :title="title + '物模型属性'"
      :visible.sync="showFormDia"
      width="70%"
      :before-close="handleClose"
      custom-class="bbsl-location-dialog"
      top="8vh"
    >
      <div class="bbsl-scroll-pane">
        <el-form
          disabled
          class="bbsl-scroll-form-spare"
          ref="formInfo"
          :rules="rules"
          :model="params"
          label-width="150px"
        >
          <el-collapse accordion v-model="activeCollapse" class="form-collapse">
            <el-collapse-item name="1">
              <template slot="title">
                <span class="collapse-title">
                  <i class="collapse-title-icon el-icon-info"></i>
                  基本信息
                </span>
              </template>
              <el-row>
                <el-col :span="12">
                  <el-form-item label="属性标识：" prop="code">
                    <el-input
                      placeholder="请输入属性标识"
                      v-model="params.code"
                    ></el-input>
                  </el-form-item>
                </el-col>
                <el-col :span="12">
                  <el-form-item label="属性名称：" prop="name">
                    <el-input
                      placeholder="请输入属性名称"
                      v-model="params.name"
                    ></el-input>
                  </el-form-item>
                </el-col>
              </el-row>
              <el-row>
                <el-col :span="12">
                  <el-form-item prop="isReadonly" label="是否只读：">
                    <el-radio-group v-model="params.isReadonly">
                      <el-radio :label="1">是</el-radio>
                      <el-radio :label="0">否</el-radio>
                    </el-radio-group>
                  </el-form-item>
                </el-col>
                <el-col :span="12">
                  <el-form-item label="属性类型：" prop="dataType">
                    <el-select
                      clearable
                      style="width: 100%"
                      v-model="params.dataType"
                      placeholder="请选择属性类型"
                      @change="changeDataType"
                    >
                      <el-option
                        v-for="item in dataTypes"
                        :key="item.value"
                        :label="item.name"
                        :value="item.value"
                      ></el-option>
                    </el-select>
                  </el-form-item>
                </el-col>
              </el-row>
              <el-row>
                <el-col :span="12">
                  <el-form-item
                    label="精度："
                    prop="dataFormart"
                    v-if="showFormData == 'float'"
                  >
                    <el-input
                      type="number"
                      min="0"
                      placeholder="小数点位数"
                      v-model="params.dataFormart"
                    ></el-input>
                  </el-form-item>
                </el-col>
                <el-col :span="12">
                  <el-form-item
                    v-if="
                      showFormData == 'int' ||
                        showFormData == 'string' ||
                        showFormData == 'float'
                    "
                    label="数据单位："
                    prop="dataUnit"
                  >
                    <el-select
                      clearable
                      style="width: 100%"
                      v-model="params.dataUnit"
                      placeholder="请选择数据单位"
                    >
                      <el-option
                        v-for="item in dataUnits"
                        :key="item.value"
                        :label="item.name"
                        :value="item.value"
                      ></el-option
                    ></el-select>
                  </el-form-item>
                </el-col>
                <el-col :span="12">
                  <el-form-item
                    v-if="showFormData == 'dateTime' || showFormData == 'date'"
                    prop="dataFormart"
                    :label="'' + time + '格式:'"
                  >
                    <el-select
                      clearable
                      style="width: 100%"
                      v-model="params.dataFormart"
                      :placeholder="'请选择' + time + '格式'"
                    >
                      <el-option
                        v-for="item in datatimes"
                        :key="item.value"
                        :label="item.name"
                        :value="item.value"
                      ></el-option
                    ></el-select>
                  </el-form-item>
                </el-col>
              </el-row>
              <el-row v-if="showFormData == 'bool' || showFormData == 'enum'">
                <el-col :span="24">
                  <el-form-item :label="'' + lableName + ''" prop="dataFormart">
                    <el-table :data="dialogData" border style="width: 100%">
                      <el-table-column label="名称">
                        <template slot-scope="scope">
                          <el-input
                            v-model="scope.row.label"
                            :disabled="boolShow"
                          ></el-input>
                        </template>
                      </el-table-column>
                      <el-table-column label="值">
                        <template slot-scope="scope">
                          <el-input v-model="scope.row.value"></el-input>
                        </template>
                      </el-table-column>
                      <el-table-column label="操作" width="150">
                        <template
                          slot-scope="scope"
                          v-if="showFormData == 'enum'"
                        >
                          <div class="column-box">
                            <i
                              class="el-icon-circle-plus"
                              style="font-size: 20px;"
                            ></i>
                            <i
                              class="el-icon-remove-outline"
                              style="font-size: 20px;"
                            ></i>
                          </div>
                        </template>
                      </el-table-column>
                    </el-table>
                  </el-form-item>
                </el-col>
              </el-row>
              <el-form-item label="备注" prop="memo">
                <el-input
                  type="textarea"
                  :autosize="{minRows: 3, maxRows: 4}"
                  placeholder="请输入备注内容"
                  v-model="params.memo"
                >
                </el-input>
              </el-form-item>
            </el-collapse-item>
          </el-collapse>
        </el-form>
      </div>
      <span slot="footer" class="dialog-footer">
        <!-- <el-button type="primary" @click="handleSave">保 存</el-button> -->
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import PhysicalModel from '@/api/device/PhysicalModel.js'
import dictUtils from '@/components/dict/DictSelectUtils.js'
export default {
  name: 'EquipAttributeDialog',
  props: {
    pId: {
      type: String,
      default: ''
    },
    parameterID: {
      type: Object,
      default: function() {
        return
      }
    }
  },
  components: {},
  data() {
    return {
      time: '时间', //时间&日期的lable
      showFormData: '', //用于判断类型显示不同输入框
      datatimes: [], // 用于动态绑定时间/日期的下拉框
      lableName: '', //布尔&枚举lable
      boolShow: false, //禁用布尔前面的key
      dialogData: [{}], //布尔&枚举存储数据
      // 字典
      dateFormarts: [],
      dateTimeFormarts: [],
      dataTypes: [],
      dataUnits: [],
      activeCollapse: '1',
      title: '新增',
      showFormDia: false,
      params: {
        code: '',
        dataFormart: '',
        dataType: '',
        dataUnit: '',
        isReadonly: 0,
        memo: '',
        name: '',
        productId: ''
      },
      rules: {
        name: [
          {
            required: true,
            message: '请输入属性名称',
            trigger: 'blur'
          }
        ],
        code: [
          {
            required: true,
            message: '请输入属性标识',
            trigger: 'blur'
          }
        ],
        dataType: [
          {
            required: true,
            message: '请选择属性类型',
            trigger: 'blur'
          }
        ],
        isReadonly: [
          {
            required: true,
            message: '请选择是否只读',
            trigger: 'blur'
          }
        ]
      }
    }
  },
  async created() {
    // 数据单位
    this.dataUnits = dictUtils.getDictItemsFromCache('sjdw')
    // 属性类型
    this.dataTypes = dictUtils.getDictItemsFromCache('sxlx')
    // 时间格式
    this.dateTimeFormarts = dictUtils.getDictItemsFromCache('sjgs')
    // 日期格式
    this.dateFormarts = dictUtils.getDictItemsFromCache('rqgs')
  },
  methods: {
    // 动态渲染数据单位,格式
    changeDataType(item) {
      if (item == '') {
        this.showFormData = item
      }
      if (item == 'string') {
        this.showFormData = item
        this.params.dataFormart = 'default'
      }
      if (item == 'int') {
        this.showFormData = item
        this.params.dataFormart = 'default'
      }
      if (item == 'float') {
        this.showFormData = item
        this.params.dataFormart = 0
      }
      if (item == 'bool') {
        this.showFormData = item
        this.lableName = '布尔值:'
        this.boolShow = true
        this.dialogData = [{}, {}]
        this.dialogData[0].label = '是'
        this.dialogData[1].label = '否'
        this.params.dataUnit = 'default'
      }
      if (item == 'date') {
        this.showFormData = item
        this.time = '日期'
        this.datatimes = this.dateFormarts
        this.params.dataFormart = 'yyyy-MM-dd'
      }
      if (item == 'dateTime') {
        this.showFormData = item
        this.time = '时间'
        this.datatimes = this.dateTimeFormarts
        this.params.dataFormart = 'yyyy-MM-dd HH:mm:ss'
      }
      if (item == 'enum') {
        this.showFormData = item
        this.lableName = '枚举项:'
        this.boolShow = false
        this.dialogData = [{}]
        this.params.dataUnit = 'default'
      }
    },
    // 布尔&枚举添加
    addTable() {
      this.dialogData.push({})
    },
    // 布尔&枚举删除
    removeTable(index) {
      if (this.dialogData.length == 1) {
        this.params.dataFormart = ''
        this.dialogData = [{}]
      } else {
        this.dialogData.splice(index, 1)
      }
    },
    // 显示
    addShow() {
      this.showFormDia = true
    },
    handleClose() {
      // 关闭前清除数据
      this.params = {
        code: '',
        dataFormart: '',
        dataType: '',
        dataUnit: '',
        isReadonly: 0,
        memo: '',
        name: '',
        productId: ''
      }
      this.title = '新增'
      this.showFormDia = false
      this.showFormData = ''
      this.boolShow = false
      this.datatimes = []
      this.dialogData = [{}]
    },
    handleSave() {
      let jsons = true
      let dtype = true
      if (this.showFormData == 'bool' || this.showFormData == 'enum') {
        // 找到导致重复的元素，ID
        // 将所有对象的ID重新组成数组
        if (this.dialogData[0].label || this.dialogData[0].value) {
          const label = this.dialogData.map(e => {
            if (e.label == '' || typeof e.label == 'undefined') {
              dtype = false
              jsons = false
              this.$message({
                message: '名称不能为空',
                type: 'warning'
              })
            } else {
              return e.label
            }
          })
          const value = this.dialogData.map(v => {
            if (v.value == '' || typeof v.value == 'undefined') {
              dtype = false
              jsons = false
              this.$message({
                message: '值不能为空',
                type: 'warning'
              })
            } else {
              return v.value
            }
          })
          if (dtype) {
            // 通过Set去除数组重复项
            const labelSet = new Set(label)
            const valueSet = new Set(value)
            // 比较两个数组的长度来判断是否存在重复项
            if ([...labelSet].length != label.length) {
              jsons = false
              this.$message({
                message: '存在相同名称',
                type: 'warning'
              })
            } else if ([...valueSet].length != value.length) {
              jsons = false
              this.$message({
                message: '存在相同值',
                type: 'warning'
              })
            } else if (
              [...labelSet].length === label.length &&
              [...valueSet].length === value.length
            ) {
              this.params.dataFormart = JSON.stringify(this.dialogData)
              jsons = true
            }
          }
        }
      }

      this.params.productId = this.parameterID.id
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          let method
          if (jsons) {
            if (!this.params.id) {
              // 新增
              method = PhysicalModel.attributeAdd
            }
            if (!!this.params.id) {
              // 修改
              method = PhysicalModel.modifyAttribute
            }
            method(this.params, res => {
              if (res.state) {
                this.$notify({
                  type: 'success',
                  message: this.title + '成功',
                  duration: 2000
                })
                this.handleClose()
                this.$emit('loadData')
              } else {
                this.$message.warning(response.message)
              }
            })
          }
        }
      })
    },
    Update(row) {
      console.log(row)
      this.title = '修改'
      this.params.id = this.pId
      this.params = row
      this.params.isReadonly = Number(row.isReadonly)
      this.showFormDia = true
      this.showFormData = row.dataType
      // 布尔值回显
      if (row.dataType == 'bool') {
        this.lableName = '布尔值:'
        this.boolShow = true
        let dataAeey = JSON.parse(row.dataFormart)
        this.dialogData = dataAeey
      }
      // 枚举项回显
      if (row.dataType == 'enum') {
        this.lableName = '枚举项:'
        this.boolShow = false
        let dataAeey = JSON.parse(row.dataFormart)
        this.dialogData = dataAeey
      }
      if (row.dataType == 'date') {
        this.time = '日期'
        this.datatimes = this.dateFormarts
      }
      if (row.dataType == 'dateTime') {
        this.time = '时间'
        this.datatimes = this.dateTimeFormarts
      }
    }
  }
}
</script>
<style lang="scss" scoped>
.redBull {
  border: 1px solid red;
}
.bbsl-scroll-form-spare {
  width: calc(100% - 20px);
  height: calc(95vh - 500px);
  overflow-y: auto;
  padding: 0 10px;
}
.column-box {
  color: #409eff;
  display: flex;
  justify-content: space-evenly;
}
</style>
